import { createRouter, createWebHistory } from 'vue-router';
import store from '@/stores/counter';
import axios from 'axios';

const system = [
  {
    path: '/system/menus',
    meta: { title: '菜单管理' },
    component: () => import('@/views/system/menus/index.vue')
  },
  {
    path: '/system/role',
    meta: { title: '角色管理' },
    component: () => import('@/views/system/role/index.vue')
  },
  {
    path: '/system/dict',
    meta: { title: '字典管理' },
    component: () => import('@/views/system/dict/index.vue')
  },
  {
    path: '/system/dictData',
    meta: { title: '字典数据管理' },
    component: () => import('@/views/system/dictData/index.vue')
  },
  {
    path: '/system/config',
    meta: { title: '平台设置' },
    component: () => import('@/views/system/config/index.vue')
  },
  {
    path: '/system/module',
    meta: { title: '模块设置' },
    component: () => import('@/views/system/module/index.vue')
  },
  {
    path: '/acccount/updatepd',
    meta: { title: '修改密码' },
    component: () => import('@/views/acccount/updatepd/index.vue')
  }
];
const user = [
  {
    path: '/user/admin',
    meta: { title: '管理员管理' },
    component: () => import('@/views/user/admin/index.vue')
  },
  {
    path: '/user/user',
    meta: { title: '用户管理' },
    component: () => import('@/views/user/user/index.vue')
  },
  {
    path: '/user/chat',
    meta: { title: '聊天记录' },
    component: () => import('@/views/user/user/chat.vue')
  }
];
const core = [
  {
    path: '/apply',
    meta: { title: '申请记录管理' },
    component: () => import('@/views/core/apply/index.vue')
  },
  {
    path: '/business',
    meta: { title: '业务管理' },
    component: () => import('@/views/core/business/index.vue')
  },
  {
    path: '/path',
    meta: { title: '申办流程管理' },
    component: () => import('@/views/core/path/index.vue')
  },
  {
    path: '/personnel',
    meta: { title: '公证员管理' },
    component: () => import('@/views/core/personnel/index.vue')
  }
];
const router = createRouter({
  history: createWebHistory(import.meta.env.BASE_URL),
  routes: [
    {
      path: '/',
      redirect: '/login'
    },
    {
      path: '/login',
      name: 'login',
      meta: { title: '赋强公证管理平台-账号登录' },
      component: () => import('@/views/login/index.vue')
    },
    {
      path: '/homeIndex',
      meta: { title: '赋强公证管理平台-系统首页' },
      component: () => import('@/components/admin-frame/home.vue'),
      children: [
        ...system,
        ...user,
        ...core,
        {
          path: '/homeIndex',
          meta: { title: '赋强公证管理平台-系统首页' },
          component: () => import('@/views/home/index.vue')
        }
      ]
    }
  ]
});
router.beforeEach(async (to, from, next) => {
  document.title = `${to.meta.title} `;
  const token = localStorage.getItem('token');
  if (to.name != 'login') {
    if (token) {
      const res = await axios.request({
        method: 'get',
        url: `${import.meta.env.VITE_REQUEST_BASE}/token/tokenView`,
        responseType: 'json',
        headers: {
          token: token
        }
      });
      if (res.data.errcode == '0') {
        store.commit('setUser', res.data.data, { root: true });
      }
      next();
    } else next('/login');
  } else next();
});

export default router;
